@@ -225,20 +225,21 @@ class CraigslistBase(object):
                           'repost_of': repost_of,
                           'name': name,
                           'url': url,
+                          # NOTE: Keeping 'datetime' for backwards
+                          # compatibility, use 'last_updated' instead.
                           'datetime': datetime,
+                          'last_updated': datetime,
                           'price': price.text if price else None,
                           'where': where,
                           'has_image': 'pic' in tags,
-                          # TODO: Look into this, looks like all show map now
-                          'has_map': 'map' in tags,
                           'geotag': None}
 
                 if self.custom_result_fields:
                     self.customize_result(result, row)
 
-                if (geotagged and result['has_map']) or include_details:
+                if geotagged or include_details:
                     detail_soup = self.fetch_content(result['url'])
-                    if geotagged and result['has_map']:
+                    if geotagged:
                         self.geotag_result(result, detail_soup)
                     if include_details:
                         self.include_details(result, detail_soup)
@@ -281,6 +282,18 @@ class CraigslistBase(object):
                      if not getattr(e, 'attrs', None))
         result['body'] = ''.join(body_text).strip()
 
+        # Add created time (in case it's different from last updated).
+        postinginfos = soup.find('div', {'class': 'postinginfos'})
+        for p in postinginfos.find_all('p'):
+            if 'posted' in p.text:
+                time = p.find('time')
+                if time:
+                    # This date is in ISO format. I'm removing the T literal
+                    # and the timezone to make it the same format as
+                    # 'last_updated'.
+                    created = time.attrs['datetime'].replace('T', ' ')
+                    result['created'] = created.rsplit(':', 1)[0]
+
         image_tags = soup.find_all('img')
         # If there's more than one picture, the first one will be repeated.
         image_tags = image_tags[1:] if len(image_tags) > 1 else image_tags
